@@ -155,6 +155,53 @@ pub trait VirtualFileSystem: Debug+Send+Sync+'static
     /// ```
     fn append_all<T: AsRef<Path>, U: AsRef<[u8]>>(&self, path: T, data: U) -> RvResult<()>;
 
+    /// Append the given line to to the target file including a newline
+    ///
+    /// * Handles path expansion and absolute path resolution
+    /// * Creates a file if it does not exist or appends to it if it does
+    ///
+    /// ### Errors
+    /// * PathError::IsNotDir(PathBuf) when the given path's parent exists but is not a directory
+    /// * PathError::DoesNotExist(PathBuf) when the given path's parent doesn't exist
+    /// * PathError::IsNotFile(PathBuf) when the given path exists but is not a file
+    ///
+    /// ### Examples
+    /// ```
+    /// use rivia::prelude::*;
+    ///
+    /// let vfs = Vfs::memfs();
+    /// let file = vfs.root().mash("file");
+    /// assert_vfs_no_file!(vfs, &file);
+    /// assert_vfs_write_all!(vfs, &file, "foobar 1");
+    /// assert!(vfs.append_line(&file, "foobar 2").is_ok());
+    /// assert_vfs_is_file!(vfs, &file);
+    /// assert_vfs_read_all!(vfs, &file, "foobar 1foobar 2\n");
+    /// ```
+    fn append_line<T: AsRef<Path>, U: AsRef<str>>(&self, path: T, line: U) -> RvResult<()>;
+
+    /// Append the given lines to to the target file including newlines
+    ///
+    /// * Handles path expansion and absolute path resolution
+    /// * Creates a file if it does not exist or appends to it if it does
+    ///
+    /// ### Errors
+    /// * PathError::IsNotDir(PathBuf) when the given path's parent exists but is not a directory
+    /// * PathError::DoesNotExist(PathBuf) when the given path's parent doesn't exist
+    /// * PathError::IsNotFile(PathBuf) when the given path exists but is not a file
+    ///
+    /// ### Examples
+    /// ```
+    /// use rivia::prelude::*;
+    ///
+    /// let vfs = Vfs::memfs();
+    /// let file = vfs.root().mash("file");
+    /// assert_vfs_no_file!(vfs, &file);
+    /// assert!(vfs.append_lines(&file, &["1", "2"]).is_ok());
+    /// assert_vfs_is_file!(vfs, &file);
+    /// assert_vfs_read_all!(vfs, &file, "1\n2\n");
+    /// ```
+    fn append_lines<T: AsRef<Path>, U: AsRef<str>>(&self, path: T, lines: &[U]) -> RvResult<()>;
+
     /// Change all file/dir permissions recursivly to `mode`
     ///
     /// * Handles path expansion and absolute path resolution
@@ -947,7 +994,7 @@ pub trait VirtualFileSystem: Debug+Send+Sync+'static
     /// ```
     fn write_all<T: AsRef<Path>, U: AsRef<[u8]>>(&self, path: T, data: U) -> RvResult<()>;
 
-    /// Write the given lines to to the target file
+    /// Write the given lines to to the target file including final newline
     ///
     /// * Handles path expansion and absolute path resolution
     /// * Create the file first if it doesn't exist or truncating it first if it does
@@ -966,7 +1013,7 @@ pub trait VirtualFileSystem: Debug+Send+Sync+'static
     /// assert_vfs_no_file!(vfs, &file);
     /// assert!(vfs.write_lines(&file, &["1", "2"]).is_ok());
     /// assert_vfs_is_file!(vfs, &file);
-    /// assert_vfs_read_all!(vfs, &file, "1\n2".to_string());
+    /// assert_vfs_read_all!(vfs, &file, "1\n2\n".to_string());
     /// ```
     fn write_lines<T: AsRef<Path>, U: AsRef<str>>(&self, path: T, lines: &[U]) -> RvResult<()>;
 }
@@ -1183,6 +1230,65 @@ impl VirtualFileSystem for Vfs
         }
     }
 
+    /// Append the given line to to the target file including a newline
+    ///
+    /// * Handles path expansion and absolute path resolution
+    /// * Creates a file if it does not exist or appends to it if it does
+    ///
+    /// ### Errors
+    /// * PathError::IsNotDir(PathBuf) when the given path's parent exists but is not a directory
+    /// * PathError::DoesNotExist(PathBuf) when the given path's parent doesn't exist
+    /// * PathError::IsNotFile(PathBuf) when the given path exists but is not a file
+    ///
+    /// ### Examples
+    /// ```
+    /// use rivia::prelude::*;
+    ///
+    /// let vfs = Vfs::memfs();
+    /// let file = vfs.root().mash("file");
+    /// assert_vfs_no_file!(vfs, &file);
+    /// assert_vfs_write_all!(vfs, &file, "foobar 1");
+    /// assert!(vfs.append_line(&file, "foobar 2").is_ok());
+    /// assert_vfs_is_file!(vfs, &file);
+    /// assert_vfs_read_all!(vfs, &file, "foobar 1foobar 2\n");
+    /// ```
+    fn append_line<T: AsRef<Path>, U: AsRef<str>>(&self, path: T, line: U) -> RvResult<()>
+    {
+        match self {
+            Vfs::Stdfs(x) => x.append_line(path, line),
+            Vfs::Memfs(x) => x.append_line(path, line),
+        }
+    }
+
+    /// Append the given lines to to the target file including newlines
+    ///
+    /// * Handles path expansion and absolute path resolution
+    /// * Creates a file if it does not exist or appends to it if it does
+    ///
+    /// ### Errors
+    /// * PathError::IsNotDir(PathBuf) when the given path's parent exists but is not a directory
+    /// * PathError::DoesNotExist(PathBuf) when the given path's parent doesn't exist
+    /// * PathError::IsNotFile(PathBuf) when the given path exists but is not a file
+    ///
+    /// ### Examples
+    /// ```
+    /// use rivia::prelude::*;
+    ///
+    /// let vfs = Vfs::memfs();
+    /// let file = vfs.root().mash("file");
+    /// assert_vfs_no_file!(vfs, &file);
+    /// assert!(vfs.append_lines(&file, &["1", "2"]).is_ok());
+    /// assert_vfs_is_file!(vfs, &file);
+    /// assert_vfs_read_all!(vfs, &file, "1\n2\n");
+    /// ```
+    fn append_lines<T: AsRef<Path>, U: AsRef<str>>(&self, path: T, lines: &[U]) -> RvResult<()>
+    {
+        match self {
+            Vfs::Stdfs(x) => x.append_lines(path, lines),
+            Vfs::Memfs(x) => x.append_lines(path, lines),
+        }
+    }
+
     /// Change all file/dir permissions recursivly to `mode`
     ///
     /// * Handles path expansion and absolute path resolution
@@ -2207,7 +2313,7 @@ impl VirtualFileSystem for Vfs
         }
     }
 
-    /// Write the given lines to to the target file
+    /// Write the given lines to to the target file including final newline
     ///
     /// * Handles path expansion and absolute path resolution
     /// * Create the file first if it doesn't exist or truncating it first if it does
@@ -2226,7 +2332,7 @@ impl VirtualFileSystem for Vfs
     /// assert_vfs_no_file!(vfs, &file);
     /// assert!(vfs.write_lines(&file, &["1", "2"]).is_ok());
     /// assert_vfs_is_file!(vfs, &file);
-    /// assert_vfs_read_all!(vfs, &file, "1\n2".to_string());
+    /// assert_vfs_read_all!(vfs, &file, "1\n2\n".to_string());
     /// ```
     fn write_lines<T: AsRef<Path>, U: AsRef<str>>(&self, path: T, lines: &[U]) -> RvResult<()>
     {
